==> jboss-4.0.2.zip: jaxrpc/src/main/org/jboss/axis/utils/IOUtils.java <==
/*
 * Copyright 2001-2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jboss.axis.utils;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;

public class IOUtils
{
   /**
    * Helper method, just calls <tt>readFully(in, b, 0, b.length)</tt>
    */
   public static int readFully(InputStream in, byte[] b)
           throws IOException
   {
      return readFully(in, b, 0, b.length);
   }

   /**
    * Same as the normal <tt>in.read(b, off, len)</tt>, but tries to ensure that
    * <p/>
    * the entire len number of bytes is read.
    * <p/>
    * <p/>
    * <p/>
    * If the end of file is reached before any bytes are read, returns -1.
    * <p/>
    * Otherwise, returns the number of bytes read.
    */
   public static int readFully(InputStream in, byte[] b, int off, int len)
           throws IOException
   {
      int total = 0;
      for (; ;)
      {
         int got = in.read(b, off + total, len - total);
         if (got < 0)
         {
            return (total == 0) ? -1 : total;
         }
         else
         {
            total += got;
            if (total == len)
               return total;
         }
      }
   }

   /** Copy the content of the given input stream to a byte array.
    */
   public static byte[] toByteArray(InputStream is)
           throws IOException
   {
      ByteArrayOutputStream baos = new ByteArrayOutputStream(1024);
      byte[] bytes = new byte[1024];
      int read = is.read(bytes);
      while (read > 0)
      {
         baos.write(bytes, 0, read);
         read = is.read(bytes);
      }
      bytes = baos.toByteArray();
      return bytes;
   }
}

==> jboss-4.0.4.zip: jaxrpc/src/main/org/jboss/axis/utils/IOUtils.java <==
/*
 * Copyright 2001-2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jboss.axis.utils;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;

import org.jboss.logging.Logger;

public class IOUtils
{
   private static Logger log = Logger.getLogger(IOUtils.class.getName());
   
   /**
    * Helper method, just calls <tt>readFully(in, b, 0, b.length)</tt>
    */
   public static int readFully(InputStream in, byte[] b) throws IOException
   {
      return readFully(in, b, 0, b.length);
   }

   /**
    * Same as the normal <tt>in.read(b, off, len)</tt>, but tries to ensure that 
    * the entire len number of bytes is read.
    * 
    * If the end of file is reached before any bytes are read, returns -1.
    * 
    * Otherwise, returns the number of bytes read.
    */
   public static int readFully(InputStream in, byte[] b, int off, int len) throws IOException
   {
      int total = 0;
      for (;;)
      {
         int got = in.read(b, off + total, len - total);
         if (got < 0)
         {
            return (total == 0) ? -1 : total;
         }
         else
         {
            total += got;
            if (total == len)
               return total;
         }
      }
   }

   /** Copy the content of the given input stream to a byte array.
    */
   public static byte[] toByteArray(InputStream is) throws IOException
   {
      ByteArrayOutputStream baos = new ByteArrayOutputStream(1024);
      byte[] bytes = new byte[1024];
      int read = is.read(bytes);
      while (read > 0)
      {
         baos.write(bytes, 0, read);
         read = is.read(bytes);
      }
      bytes = baos.toByteArray();
      return bytes;
   }

   public static InputStream debugInputStream(InputStream isIn, String charsetName) 
   {
      InputStream isOut = isIn;
      if (log.isDebugEnabled())
      {
         try
         {
            if (charsetName == null)
               charsetName = "UTF-8";

            byte[] barr = toByteArray(isIn);
            String str = new String(barr, charsetName);
            log.debug(charsetName + ": " + str);
            
            isOut = new ByteArrayInputStream(barr);
         }
         catch (IOException ex)
         {
            log.error("Cannot debug input stream", ex);
         }
      }
      return isOut;
   }
}
